summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenerators/simplecodegenerator.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-12 01:36:19 +0000
commit99a2774ca6f1cab334de5d43fe36fc44ae889a4c (patch)
treeeff34cf0762227f6baf2a93e8fef48d4bed2651c /umbrello/umbrello/codegenerators/simplecodegenerator.cpp
parent1c104292188541106338d4940b0f04beeb4301a0 (diff)
downloadtdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.tar.gz
tdesdk-99a2774ca6f1cab334de5d43fe36fc44ae889a4c.zip
TQt4 convert kdesdk
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1236185 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/codegenerators/simplecodegenerator.cpp')
-rw-r--r--umbrello/umbrello/codegenerators/simplecodegenerator.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/umbrello/umbrello/codegenerators/simplecodegenerator.cpp b/umbrello/umbrello/codegenerators/simplecodegenerator.cpp
index 6b7ac992..d4f62cc3 100644
--- a/umbrello/umbrello/codegenerators/simplecodegenerator.cpp
+++ b/umbrello/umbrello/codegenerators/simplecodegenerator.cpp
@@ -47,10 +47,10 @@
SimpleCodeGenerator::SimpleCodeGenerator (bool createDirHierarchyForPackages /* =true */)
{
m_indentLevel = 0;
- UMLDoc * parentDoc = UMLApp::app()->getDocument();
- parentDoc->disconnect(this); // disconnect from UMLDoc.. we arent planning to be synced at all
+ UMLDoc * tqparentDoc = UMLApp::app()->getDocument();
+ tqparentDoc->disconnect(this); // disconnect from UMLDoc.. we arent planning to be synced at all
m_createDirHierarchyForPackages = createDirHierarchyForPackages;
- initFields(parentDoc);
+ initFields(tqparentDoc);
}
SimpleCodeGenerator::~SimpleCodeGenerator ( ) { }
@@ -77,7 +77,7 @@ TQString SimpleCodeGenerator::getIndent ()
TQString SimpleCodeGenerator::findFileName(UMLPackage* concept, const TQString &ext) {
//if we already know to which file this class was written/should be written, just return it.
- if (m_fileMap.contains(concept))
+ if (m_fileMap.tqcontains(concept))
return m_fileMap[concept];
//else, determine the "natural" file name
@@ -89,16 +89,16 @@ TQString SimpleCodeGenerator::findFileName(UMLPackage* concept, const TQString &
package.simplifyWhiteSpace();
// Replace all blanks with underscore
- package.replace(TQRegExp(" "), "_");
+ package.tqreplace(TQRegExp(" "), "_");
// Convert all "::" to "/" : Platform-specific path separator
- // package.replace(TQRegExp("::"), "/");
+ // package.tqreplace(TQRegExp("::"), "/");
// if package is given add this as a directory to the file name
if (!package.isEmpty() && m_createDirHierarchyForPackages) {
name = package + '.' + concept->getName();
- name.replace(TQRegExp("\\."),"/");
- package.replace(TQRegExp("\\."), "/");
+ name.tqreplace(TQRegExp("\\."),"/");
+ package.tqreplace(TQRegExp("\\."), "/");
package = '/' + package;
} else {
name = concept->getFullyQualifiedName("-");
@@ -136,10 +136,10 @@ TQString SimpleCodeGenerator::findFileName(UMLPackage* concept, const TQString &
name.simplifyWhiteSpace();
- name.replace(TQRegExp(" "),"_");
+ name.tqreplace(TQRegExp(" "),"_");
TQString extension = ext.simplifyWhiteSpace();
- extension.replace(' ', '_');
+ extension.tqreplace(' ', '_');
return overwritableName(concept, name, extension);
}
@@ -256,14 +256,14 @@ void SimpleCodeGenerator::writeCodeToFile ( UMLClassifierList & concepts) {
this->writeClass(c); // call the writer for each class.
}
-void SimpleCodeGenerator::initFields ( UMLDoc * parentDoc ) {
+void SimpleCodeGenerator::initFields ( UMLDoc * tqparentDoc ) {
- // load Classifier documents from parent document
+ // load Classifier documents from tqparent document
// initFromParentDocument();
m_fileMap.clear();
m_applyToAllRemaining = true;
- m_doc = parentDoc;
+ m_doc = tqparentDoc;
// this really is just being used to sync the internal params
// to the codegenpolicy as there are no code documents to really sync.
@@ -282,7 +282,7 @@ void SimpleCodeGenerator::syncCodeToDocument() {
}
// override parent method
void SimpleCodeGenerator::initFromParentDocument( )
{
// Do nothing
@@ -282,7 +282,7 @@ void SimpleCodeGenerator::syncCodeToDocument() {
}
-// override parent method
+// override tqparent method
void SimpleCodeGenerator::initFromParentDocument( )
{